@@ -5,13 +5,23 @@ $(function () {
       processData: false,
       contentType: false,
       data: new FormData($(this)[0]),
-      dataType: 'text'
+      dataType: 'json'
     }).done(function(data) {
-      $('#result').slideDown("fast").find('textarea').val(data);
+      $('#result').slideDown("fast").find('textarea').val(data.content);
+
+      var error = $('#error');
+      error.empty();
+      for (var i = 0; i < data.errors.length; ++i) {
+        var element = $('<pre/>');
+        element.addClass(data.errors[i].type);
+        element.text(data.errors[i].message);
+        error.append(element);
+      }
+      $('#error').slideDown("fast").find('textarea').val(data.error);
 
       // Download Anchor
       var filename = $('#form').find('.fileupload-preview').text().replace(/.md$/, ".txt");
-      var blob = new Blob([ data ], {"type": "text/plain"});
+      var blob = new Blob([ data.content ], {"type": "text/plain"});
       window.URL = window.URL || window.webkitURL;
       $('#download').attr("href", window.URL.createObjectURL(blob)).attr("download", filename);
     }).fail(function(data) {
@@ -44,3 +54,4 @@ $(function () {
     $('#blank_style').toggle();
   });
 });
+// vim: set tabstop=2 expandtab:
